/*
 * Copyright (C) 2001, 2002 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * The Sun (tm) Java Advanced Imaging library (JAI), The Sun JIMI library
 * (or with modified versions of the above that use the same license as the above),
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.util;

import java.io.File;
import java.io.IOException;

/**
 * Class to do locking by way of a file:
 * existence of the file means the lock is enabled.
 */
public class LockFile {
  private File file;

  /**
   * Creates an instance based on a filename
   */
  public LockFile(String aFileName) {
    file = new File(aFileName);
  }

  public LockFile(File aFile) {
    file = new File(aFile.getAbsolutePath());
  }

  /**
   * Tries to enable the lock. Returns <code>true</code> on success.
   */
  public boolean lock() throws IOException {
    if (file.createNewFile()) {
      file.deleteOnExit();
      return true;
    }
    else {
      return false;
    }
  }

  /**
   * Returns <code>true</code> if locked, either by external parties
   * or by this object.
   */
  public boolean isLocked() {
    return file.exists();
  }

  /**
   * Removes the lock, wether it was enabled by this object or by
   * an external party.
   */
  public void unlock() {
    file.delete();
  }
}
